/*
  The ATM remote software controls the remote. This part takes 8 analog inputs and converts them to a serial stream.
  It also has 3 buttons, These start or stop the stream
  The serial stream happens at 9600 baud to guarantee integrity of the signal
*/

uint8_t analog_inputs[8] = {A0, A1, A2, A3, A4, A5, A6, A7};
uint8_t button[3] = {4, 2, 3};

uint8_t button_history[3];
uint16_t analog_reads[8];
uint32_t read_delay = 100; //in millisecond, how often to read
uint32_t read_target;
uint8_t read_active = 0;
uint8_t lock_rotation = 0;
uint8_t lock_gripper = 0;


void setup() {
  Serial.begin(9600);
  for (uint8_t b = 0; b < 3; b++) {
    pinMode(button[b], INPUT_PULLUP);
  }
  for (uint8_t a = 0; a < 8; a++) {
    pinMode(analog_inputs[a], INPUT);
  }


}

void loop() {  
  if (millis() > read_target) { //if the value needs an update
    read_target = millis() + read_delay; //set new target

    //check buttons
    //check start-stop
    if (digitalRead(button[0]) == 0 && button_history[0] == 1) { //if button 0 became high (inverted bacause pullup)
      //toggle active state
      if (read_active == 0) {
        read_active = 1;
        Serial.println("STRT");
      }
      else {
        read_active = 0;
        Serial.println("STOP");
      }
    }

    //check rotation
    if (digitalRead(button[1]) == 0 && button_history[1] == 1) { //if button 0 became high (inverted bacause pullup)
      //toggle active state
      if (lock_rotation == 0) {
        lock_rotation = 1;
        Serial.println("STRR");
      }
      else {
        lock_rotation = 0;
        Serial.println("STOR");
      }
    }

    //check gripper
    if (digitalRead(button[2]) == 0 && button_history[2] == 1) { //if button 0 became high (inverted bacause pullup)
      //toggle active state
      if (lock_gripper == 0) {
        lock_gripper = 1;
        Serial.println("STRG");
      }
      else {
        lock_gripper = 0;
        Serial.println("STOG");
      }
    }

    //set button history
    for (uint8_t b = 0; b < 3; b++) {
      button_history[b] = digitalRead(button[b]);
    }

    //if read is active, get values and send them
    if (read_active == 1){
      Serial.print("APOS");
      for (uint8_t a = 0; a < 8; a++){
        analog_reads[a] = analogRead(analog_inputs[a]);
        Serial.print(" ");
        Serial.print(analog_reads[a]);
        
      }
      Serial.println("");
    }
  }
}
